shcolors package
================

Submodules
----------

shcolors.cli module
-------------------

.. automodule:: shcolors.cli
    :members:
    :undoc-members:
    :show-inheritance:

shcolors.shcolors module
------------------------

.. automodule:: shcolors.shcolors
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: shcolors
    :members:
    :undoc-members:
    :show-inheritance:
